#
# spec file for package python-msgpack
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without test

%define oldpython python
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-msgpack
Version:        0.5.6
Release:        150100.3.3.1
Summary:        MessagePack (de)serializer
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://msgpack.org/
Source:         https://files.pythonhosted.org/packages/source/m/msgpack/msgpack-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
# was renamed at 0.5.0
Provides:       python-msgpack-python = %{version}
Obsoletes:      python-msgpack-python < 0.5.0
%ifpython2
Provides:       %{oldpython}-msgpack-python = %{version}
Obsoletes:      %{oldpython}-msgpack-python < 0.5.0
%endif
%if %{with test}
# Test requirements:
BuildRequires:  %{python_module pytest}
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%python_subpackages

%description
MessagePack (de)serializer for Python.

MessagePack is a binary-based efficient data interchange format that is
focused on high performance. It is like JSON, but very fast and small.

%prep
%setup -q -n msgpack-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%if %{with test}
%check
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
py.test-%{$python_bin_suffix}
}
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc README.rst
%license COPYING
%{python_sitearch}/msgpack
%{python_sitearch}/msgpack-%{version}*-info

%changelog
* Tue Sep 27 2022 mcepl@suse.com
- Loose the filelist for the package info to avoid FTBFS on
  SLE-15-SP5 (bsc#1203743).
* Tue Jan 29 2019 alarrosa@suse.com
- Use %%license
* Thu Mar  1 2018 alarrosa@suse.com
- Update to version 0.5.6 (boo#1123558)
  * Fix fallback.Unpacker.feed() dropped unused data from buffer
  * Resurrect fallback.unpack() and _unpacker.unpack(). They were
    removed at 0.5.5 but it breaks backward compatibility.
- Update to version 0.5.5
  * Fix memory leak in pure Python Unpacker.feed()
  * Fix unpack() didn't support raw option
* Mon Feb 26 2018 alarrosa@suse.com
- Provide also python-msgpack-python in the python2 package to
  be able to obsolete the python2-msgpack-python package correctly.
* Mon Feb 12 2018 dmueller@suse.com
- fix typo in obsoletes
* Tue Feb  6 2018 tbechtold@suse.com
- update to version 0.5.4
  * packer: Use PyUnicode_AsUTF8AndSize() for utf-8 (#272)
  * Fix encoding and unicode_errors (#277)
  * Undeprecate unicode_errors (#278)
  * Packer.pack() reset buffer on exception (#274)
  * Use cython's cast for converting encoding and errors (#279)
  * 0.5.4
  * Add raw_as_bytes option to Unpacker. (#265)
  * s/raw_as_bytes/raw/g (#276)
* Tue Jan 30 2018 jengelh@inai.de
- Strip rheotrics from descriptions.
* Sat Jan 27 2018 dmueller@suse.com
- update to 0.5.1:
  * Package name on PyPI was changed to msgpack from 0.5.
- rename from msgpack-python
* Wed Apr 19 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Tue Nov 15 2016 dmueller@suse.com
- update to 0.4.8
* Sat Oct 17 2015 mc@suse.com
- build conditionally without tests
* Mon Mar 16 2015 hpj@urpla.net
- Update to version 0.4.6
  * fallback.Unpacker: Fix Data corruption when OutOfData. This bug
    only affects "Streaming unpacking."
- Changes from version 0.4.5
  * Fix test failure on pytest 2.3.
  * Fix typos in ChangeLog.
  * Improve README.rst
- Changes from version 0.4.4
  * Fix compile error.
- Changes from version 0.4.3
  * Unpacker may unpack wrong uint32 value on 32bit or LLP64
    environment. (#101)
  * Build failed on Windows Python 2.7.
* Tue Nov 18 2014 toddrme2178@gmail.com
- Update to 0.4.2
  Bugfixes
  - Unpacker doesn't increment refcount of ExtType hook.
  - Packer raises no exception for inputs doesn't fit to msgpack format.
- Update to 0.4.1
  Changes
  - fallback.Unpacker.feed() supports bytearray.
  Bugs fixed
  - Unpacker doesn't increment refcount of hooks. Hooks may be GCed while unpacking.
  - Unpacker may read unfilled internal buffer.
* Sun Dec  8 2013 p.drouand@gmail.com
- Update to version 0.4.0
  + Raises TypeError instead of ValueError when packer receives
    unsupported type.
  + Support New msgpack spec.
- Use download Url as source
- Add python-argparse requirement for SLE11SP3 to get tests working
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu May  2 2013 speilicke@suse.com
- Package COPYING and README.rst
- Run testsuite
* Mon Feb 18 2013 alexandre@exatati.com.br
- Update to 0.3.0:
  Incompatible Changes
  - Default value of use_list is True for now. (It was False for
    0.2.x) You should pass it explicitly for compatibility to 0.2.x.
  Changes
  - Pure Python fallback module is added. (thanks to bwesterb)
  - Add .skip() method to Unpacker (thanks to jnothman)
  - Add capturing feature. You can pass the writable object to
    Unpacker.unpack() as a second parameter.
  - Add Packer.pack_array_header and Packer.pack_map_header. These
    methods only pack header of each type.
  - Add autoreset option to Packer (default: True). Packer doesn't
    return packed bytes and clear internal buffer.
  - Add Packer.pack_map_pairs. It packs sequence of pair to map type.
* Mon Jan 14 2013 saschpe@suse.de
- Simplify macro usage
* Fri Jan 11 2013 p.drouand@gmail.com
- Initial python3 support
* Sat Dec 22 2012 alexandre@exatati.com.br
- Update to 0.2.4:
  - Fix SEGV when object_hook or object_pairs_hook raise Exception. (#39)
* Tue Dec 11 2012 alexandre@exatati.com.br
- Update to 0.2.3:
  - Warn when use_list is not specified. It's default value will be
    changed in 0.3.
  - Can't pack subclass of dict.
* Fri Sep 21 2012 alexandre@exatati.com.br
- Update to 0.2.2:
  - Add use_single_float option to Packer. When it is true, packs
    float object in single precision format.
  - unpack() didn't restores gc state when it called with gc
    disabled. unpack() doesn't control gc now instead of restoring
    gc state collectly. User can control gc state when gc cause
    performance issue.
  - Unpacker's read_size option didn't used.
* Mon Aug 20 2012 alexandre@exatati.com.br
- Update to 0.2.1:
  - Add max_buffer_size parameter to Unpacker. It limits internal
    buffer size and allows unpack data from untrusted source safely.
  - Unpacker's buffer reallocation algorithm is less greedy now. It
    cause perforamce derease in rare case but memory efficient and
    don't allocate than max_buffer_size.
  - Fix msgpack didn't work on SPARC Solaris. It was because
    choosing wrong byteorder on compilation time. Use sys.byteorder
    to get correct byte order. Very thanks to Chris Casey for giving
    test environment to me.
* Wed Jun 27 2012 alexandre@exatati.com.br
- Update to 0.2.0:
  - Sorry, no changelog.
* Fri Jun 22 2012 alexandre@exatati.com.br
- Initial package (0.1.13) for openSUSE.
